# I'm not able to verify what are licences for my test images
# If these are yours and you don't want them here, let me know and I'll use different

import os
import unittest
import hashlib

import requests
import pixhostuploader as pixhost

_cd = os.path.dirname(os.path.realpath(__file__))


class PixhostFirstTestCase(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(PixhostFirstTestCase, self).__init__(*args, **kwargs)
        self.uploaded = None
        self.images = [
            os.path.join(_cd, 'IBM_PCjr_System_1.jpg'),
            os.path.join(_cd, 'ibm5150.jpg'),
        ]
        self.uploaded = pixhost.upload(self.images)

    def test_upload(self):
        self.assertEqual(len(self.uploaded), len(self.images))
        for upload in self.uploaded:
            self.assertIsInstance(upload['thumb_image'], str)
            self.assertTrue(len(upload['thumb_image']) > 0)
            self.assertIsInstance(upload['full_size_image'], str)
            self.assertTrue(len(upload['full_size_image']) > 0)
            self.assertIsInstance(upload['page_url'], str)
            self.assertTrue(len(upload['page_url']) > 0)

    def test_status_codes(self):
        test_img_response = requests.get(self.uploaded[0]['full_size_image'])
        self.assertEqual(test_img_response.status_code, 200)

        # check the thumb exists
        self.assertEqual(requests.get(self.uploaded[0]['thumb_image']).status_code, 200)

        # url with image page on pixhost.org exists
        self.assertEqual(requests.get(self.uploaded[0]['page_url']).status_code, 200)

    def test_md5(self):
        # download the uploaded file
        test_img_response = requests.get(self.uploaded[0]['full_size_image'])

        # check md5 of both files
        uploaded_md5 = hashlib.md5(test_img_response.content).hexdigest()
        with open(self.images[0], 'rb') as f:
            orig_md5 = hashlib.md5(f.read()).hexdigest()
        self.assertEqual(uploaded_md5, orig_md5)

class PixhostSecondTestCase(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(PixhostSecondTestCase, self).__init__(*args, **kwargs)
        self.image = os.path.join(_cd, 'ibm5150.jpg')
        self.uploaded = pixhost.upload(self.image)

    def test_md5(self):
        test_img_response = requests.get(self.uploaded['full_size_image'])
        uploaded_md5 = hashlib.md5(test_img_response.content).hexdigest()
        with open(self.image, 'rb') as f:
            orig_md5 = hashlib.md5(f.read()).hexdigest()

        self.assertEqual(uploaded_md5, orig_md5)

if __name__ == '__main__':
    unittest.main()


import os
from http.cookiejar import CookieJar
import requests
from lxml import html


PIXHOST_HOMEPAGE_URL = 'http://www.pixhost.org/'
PIXHOST_UPLOAD_URL = 'http://www.pixhost.org/classic-upload/'


def upload(images, adult=False):
    source_images = images if isinstance(images, list) else [images]

    params = {
        'content_type': int(adult),
        'tos': 'on'
    }

    # fake headers
    headers = {
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36',
        'Referer': 'http://www.pixhost.org/classic-upload/',
        'Origin': 'http://www.pixhost.org',
        'Host': 'www.pixhost.org',
    }

    files = []
    # add images to parameter lists
    for img in source_images:
        if os.path.getsize(img) > pow(10, 7):
            raise TooLargeImageFormat()

        files.append(('img[]', (os.path.basename(img), open(img, 'rb'))))


    # make first request to the homepage to fill cookie jar with default cookies
    jar = CookieJar()
    requests.post(PIXHOST_HOMEPAGE_URL, cookies=jar, headers=headers)

    # upload images
    response = requests.post(PIXHOST_UPLOAD_URL, data=params, cookies=jar, headers=headers, files=files)

    for file in files:
        file[1][1].close()

    if response.status_code != 200:
        raise UploadFailed(response)

    # urls for uploaded images
    image_urls = []

    root = html.fromstring(response.text)

    main_div = root.xpath('//div[@id="text"]')

    # fetch small thumbnails
    all_small_thumbs = main_div[0].xpath('./a')

    for thumb_elm in all_small_thumbs:
        # we need to download the page with fullsize image
        full_size_preview_url = thumb_elm.attrib['href']
        preview_response = requests.get(full_size_preview_url, headers=headers, cookies=jar)
        preview_root = html.fromstring(preview_response.text)

        image_urls.append({
            'thumb_image': thumb_elm.xpath('./img')[0].attrib['src'],
            'full_size_image': preview_root.xpath('//img[@id="show_image"]')[0].attrib['src'],
            'page_url': full_size_preview_url  # you probably won't need this
        })

    return image_urls if isinstance(images, list) else image_urls[0]


class UploadFailed(Exception):
    pass


class TooLargeImageFormat(Exception):
    pass


from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

setup(
    name='pixhostuploader',
    version='1.0.2',
    description='Unofficial uploader to pixhost.org image sharing site.',
    long_description=readme(),
    url='https://github.com/martinsik/pixhost-uploader',
    author='Martin Sikora',
    author_email='martin.sikora.ahoj@gmail.com',
    license='MIT',
    packages=['pixhostuploader', 'tests'],
    classifiers=[
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet',
        'Topic :: Multimedia :: Graphics',
        'Topic :: Utilities',
    ],
    install_requires=[
        'requests',
        'lxml'
    ],
    test_suite='tests',
)